@@ -7,7 +7,7 @@
 #include <objc/Object.h>
 #include <gtk/gtk.h>
 #include <gnome.h>
-#include "obgtk/obgtk.h"
+#include <obgtk/obgtk.h>
 
 #include <obgnome/obgnomeAbout.h>
 #include <obgnome/obgnomeApp.h>
@@ -18,20 +18,26 @@
 #include <obgnome/obgnomeEntry.h>
 #include <obgnome/obgnomeFileEntry.h>
 #include <obgnome/obgnomeFontSelector.h>
-#include <obgnome/obgnomeIconList.h>
-#include <obgnome/obgnomeLED.h>
+/*#include <obgnome/obgnomeIconList.h>*/
 #include <obgnome/obgnomeLess.h>
 #include <obgnome/obgnomeMessageBox.h>
 #include <obgnome/obgnomePixmap.h>
 #include <obgnome/obgnomePropertyBox.h>
-#include <obgnome/obgnomeRootWin.h>
 #include <obgnome/obgnomeStockButton.h>
 #include <obgnome/obgnomeStock.h>
+
+#ifdef GTKTTY_WAS_RESURRECTED
+#include <obgnome/obgnomeLED.h>
 #include <obgnome/obgnomeTTY.h>
 #include <obgnome/obgnomeTerm.h>
 #include <obgnome/obgnomeVtEmu.h>
+#endif
+
+#include <obgnome/obgnomeCanvas.h>
+#include <obgnome/obgnomeCanvasLine.h>
+#include <obgnome/obgnomeCanvasRectEllipse.h>
+#include <obgnome/obgnomeCanvasText.h>
+#include <obgnome/obgnomeCanvasWidget.h>
 
-#include <obgnome/obgtkCalendar.h>
 
 #endif /* OBGNOME_H */
-
