@@ -15,13 +15,9 @@
 - initWithCListInfoTitles:(gint) ncolumns
 		   Titles:(const gchar **)titles 
 {
-  return [self castGtkCList:GTK_CLIST(gtk_clist_new_with_titles(ncolumns, titles))];
-}
-
-- set_border:(GtkShadowType) border
-{
-  gtk_clist_set_border(gtkclist, border);
-  return self;
+  return [self
+	   castGtkCList:GTK_CLIST(gtk_clist_new_with_titles(ncolumns,
+							    (char **)titles))];
 }
 
 - set_selection_mode:(GtkSelectionMode) mode
@@ -139,13 +135,13 @@
 
 - (gint)appendCListRow:(const gchar **) text
 {
-  return gtk_clist_append(gtkclist, text);
+  return gtk_clist_append(gtkclist, (char **)text);
 }
 
-- insertCListRow:( const gchar **) text
-		:(gint) row
+- insertCListRow:(gint) row
+		:(const gchar **) text
 {
-  gtk_clist_insert(gtkclist, row, text);
+  gtk_clist_insert(gtkclist, row, (char **)text);
   return self;
 }
 
