@@ -27,23 +27,6 @@
   return self;
 }
 
-- block_resize
-{
-  gtk_container_block_resize(gtkcontainer);
-  return self;
-}
-
-- unblock_resize
-{
-  gtk_container_unblock_resize(gtkcontainer);
-  return self;
-}
-
-- (gint)need_resize
-{
-  return gtk_container_need_resize(gtkcontainer);
-}
-
 - foreach:
  callback:(GtkCallback) acallback
 callbackData:(gpointer) callback_data
