@@ -1,4 +1,4 @@
-#include "obgtk.h"
+#include "obgtkCurve.h"
 
 @implementation Gtk_Curve
 - castGtkCurve:(GtkCurve *)castitem
@@ -36,14 +36,14 @@
 }
 
 - get_vector:(int) veclen
-     aVector:(gfloat *) vector
+   getVector:(gfloat *) vector
 {
   gtk_curve_get_vector(gtkcurve, veclen, vector);
   return self;
 }
 
 - set_vector:(int) veclen
-     aVector:(gfloat *) vector
+   getVector:(gfloat *) vector
 {
   gtk_curve_set_vector(gtkcurve, veclen, vector);
   return self;
