@@ -12,7 +12,7 @@
 
 - castGtkLabel:(GtkLabel *) castitem;
 - initWithLabel:(gchar *) str;
-- set:(gchar *) str;
+- set_text:(gchar *) str;
 - get:(gchar **) str;
 - set_justify:(GtkJustification) just;
 @end
