@@ -18,9 +18,9 @@
   return [self castGtkLabel:GTK_LABEL(gtk_label_new(str))];
 }
 
-- set:(gchar *) str
+- set_text:(gchar *) str
 {
-  gtk_label_set(gtklabel, str);
+  gtk_label_set_text(gtklabel, str);
   return self;
 }
 
