@@ -1,9 +1,10 @@
-#include "obgtk.h"
+#include "obgtkVBox.h"
 
 @implementation Gtk_VBox
 - castGtkVBox:(GtkVBox *)castitem
 {
-  return [super castGtkBox:GTK_BOX(castitem)];
+  self = [super castGtkBox:GTK_BOX(castitem)];
+  return self;
 }
 
 - init
