@@ -31,7 +31,7 @@
 - add_accelerator_table:(Gtk_AcceleratorTable *) table;
 - remove_accelerator_table:(Gtk_AcceleratorTable *) table;
 #endif
-- position:(GtkWindowPosition) position;
+- set_position:(GtkWindowPosition) position;
 
 @end
 
